dnl ---------------------------------------------------------------------------
dnl Author:          Francesco Montorsi
dnl                  (contributions by David Hart)
dnl Creation date:   13/9/2005
dnl RCS-ID:          $Id: wxpresets.m4,v 1.8 2005/12/31 11:30:14 frm Exp $
dnl Purpose:         Some M4 macros which makes *much* easier writing the
dnl                  configure.ac files for build system based on wxpresets
dnl ---------------------------------------------------------------------------


dnl ---------------------------------------------------------------------------
dnl Macros for wxWidgets build configuration detection.
dnl Typically used in configure.in/ac as:
dnl
dnl     # basic configure checks
dnl     ...
dnl
dnl     # required library checks
dnl     AM_WXPRESETS_FULL([2.6.1], [net,xrc,stc])
dnl     ...
dnl
dnl     # write the output files
dnl     AC_BAKEFILE([m4_incl ude(autoconf_inc.m4)])
dnl     AC_CONFIG_FILES([Makefile ...])
dnl     AC_OUTPUT
dnl
dnl     # end of the configure.in script
dnl     AM_WXPRESETS_MSG        # optional: just to show a message to the user
dnl
dnl ---------------------------------------------------------------------------


dnl ---------------------------------------------------------------------------
dnl AM_YESNO_OPTCHECK([name of the boolean variable to set],
dnl                   [name of the --enable-option variable with yes/no values],
dnl                   [name of the --enable option])
dnl
dnl Converts the $3 variable, suppose to contain a yes/no value to a 1/0
dnl boolean variable and saves the result into $1.
dnl Outputs also the standard checking-option message.
dnl ---------------------------------------------------------------------------
AC_DEFUN([AM_YESNO_OPTCHECK],
        [
        AC_MSG_CHECKING([for $3 option])
        if [[ "x$$2" = "xyes" ]]; then
            AC_MSG_RESULT([yes])
            $1=1
        else
            AC_MSG_RESULT([no])
            $1=0
        fi
    ])


dnl ---------------------------------------------------------------------------
dnl AM_WXFLAGS_CONTAIN / AM_WXSELECTEDCONFIG_CONTAIN ([RESULTVAR], [STRING])
dnl
dnl Sets to nonzero the variable named "WX_$RESULTVAR" if the wxWidgets
dnl additional CPP flags (taken from $WX_CPPFLAGS) contain the given STRING.
dnl Otherwise the variable will be set to 0.
dnl
dnl NOTE: 'expr match STRING REGEXP' cannot be used since on Mac it doesn't work;
dnl       we'll use 'expr STRING : REGEXP' instead
dnl ---------------------------------------------------------------------------
AC_DEFUN([AM_WXFLAGS_CONTAIN],
        [
        WX_$1=$(expr "$WX_CPPFLAGS" : ".*$2.*")
    ])

AC_DEFUN([AM_WXSELECTEDCONFIG_CONTAIN],
        [
        WX_$1=$(expr "$WX_SELECTEDCONFIG" : ".*$2.*")
    ])


dnl ---------------------------------------------------------------------------
dnl AM_WXFLAGS_CHECK([RESULTVAR], [STRING], [MSG] [, ACTION-IF-FOUND
dnl                                               [, ACTION-IF-NOT-FOUND]])
dnl
dnl Outputs the given MSG. Then searches the given STRING in the wxWidgets
dnl additional CPP flags and put the result of the search in WX_$RESULTVAR
dnl also adding the "yes" or "no" message result to MSG.
dnl ---------------------------------------------------------------------------
AC_DEFUN([AM_WXFLAGS_CHECK],
        [
        if test "$$1" = "wxlike" ; then

            dnl The user does not have particular preferences for this option;
            dnl so we will detect the wxWidgets relative build setting and will use it
            AC_MSG_CHECKING([$3])
            AM_WXFLAGS_CONTAIN([$1], [$2])
            if test "$WX_$1" != "0"; then
                WX_$1=1
                AC_MSG_RESULT([yes])
                ifelse([$4], , :, [$4])
            else
                WX_$1=0
                AC_MSG_RESULT([no])
                ifelse([$5], , :, [$5])
            fi
        else

            dnl Use the setting given by the user
            WX_$1=$$1
        fi
    ])

AC_DEFUN([AM_WXSELECTEDCONFIG_CHECK],
        [
        if test "$$1" = "wxlike" ; then

            dnl The user does not have particular preferences for this option;
            dnl so we will detect the wxWidgets relative build setting and will use it
            AC_MSG_CHECKING([$3])
            AM_WXSELECTEDCONFIG_CONTAIN([$1], [$2])
            if test "$WX_$1" != "0"; then
                WX_$1=1
                AC_MSG_RESULT([yes])
                ifelse([$4], , :, [$4])
            else
                WX_$1=0
                AC_MSG_RESULT([no])
                ifelse([$5], , :, [$5])
            fi
        else

            dnl Use the setting given by the user
            WX_$1=$$1
        fi
    ])



dnl ---------------------------------------------------------------------------
dnl AM_WXPRESETS_CHECK([minimum-wx-version], [])
dnl
dnl Sets the WX_UNICODE, WX_DEBUG, WX_SHARED, WX_VERSION variables to the right
dnl values looking at the current $WX_CPPFLAGS variable.
dnl To set the $WX_CPPFLAGS variable you need to use AM_PATH_WXCONFIG first.
dnl
dnl Then sets the WX_GTKPORT, WX_MOTIFPORT, WX_MACPORT, WXX11PORT, WXMGLPORT, WXMSWPORT
dnl flags to 1 or 0 to match the current wxWidgets port used.
dnl Also sets the WX_PORT var to one of gtk,motif,mac,x11,mgl,msw values.
dnl ---------------------------------------------------------------------------
AC_DEFUN([AM_WXPRESETS_CHECK],
        [
        dnl be sure that the WX_VERSION macro has the same format of the WX_VERSION option
        dnl which is used by wx_win32.bkl (i.e. 25, 26, 27... instead of 2.5.x, 2.6.x, 2.7.x...)
        wx_config_major_version=`echo $WX_VERSION | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\1/'`
        wx_config_minor_version=`echo $WX_VERSION | \
           sed 's/\([[0-9]]*\).\([[0-9]]*\).\([[0-9]]*\)/\2/'`
        WX_VERSION=$wx_config_major_version$wx_config_minor_version


        dnl FOR DEBUG ONLY
        if test "$DBG_CONFIGURE" = "1"; then
            echo "WX_VERSION: $WX_VERSION"
        fi


        if test $WX_VERSION -gt 26 ; then

            dnl The wx-config we are using understands the "--selected_config" option
            dnl which returns an easy-parsable string !

            WX_SELECTEDCONFIG=$($WX_CONFIG_WITH_ARGS --selected_config)

            dnl FOR DEBUG ONLY
            if test "$DBG_CONFIGURE" = "1"; then
                echo "Using wx-config --selected_config; WX_SELECTEDCONFIG: $WX_SELECTEDCONFIG"
            fi


            AM_WXSELECTEDCONFIG_CHECK([UNICODE], [unicode], [if wxWidgets was built with UNICODE enabled])
            AM_WXSELECTEDCONFIG_CHECK([DEBUG], [debug], [if wxWidgets was built in DEBUG mode])

            dnl we could test directly for WX_SHARED with a line like:
            dnl    AM_WXSELECTEDCONFIG_CHECK([SHARED], [shared], [if wxWidgets was built in SHARED mode])
            dnl since wx-config --selected-config outputs the 'shared' word when wx was built in shared mode.
            dnl However that wouldn't work since we define the '--enable-static' option and not the
            dnl '--enable-shared' option (just as wx does) and thus at this point we have an empty WX_SHARED
            dnl variable; the right variable to use is WX_STATIC which is initialized to 'wxlike' here...
            AM_WXSELECTEDCONFIG_CHECK([STATIC], [static], [if wxWidgets was built in STATIC mode])
            if test "$WX_STATIC" != "0"; then
                WX_SHARED=0
            else
                WX_SHARED=1
            fi

            dnl checks for the wx port used
            WX_PORT="unknown"
            AM_WXSELECTEDCONFIG_CHECK([GTKPORT], [gtk], [if wxWidgets port is wxGTK], [WX_PORT="gtk"])
            AM_WXSELECTEDCONFIG_CHECK([MOTIFPORT], [motif], [if wxWidgets port is wxMotif], [WX_PORT="motif"])
            AM_WXSELECTEDCONFIG_CHECK([MACPORT], [mac], [if wxWidgets port is wxMac], [WX_PORT="mac"])
            AM_WXSELECTEDCONFIG_CHECK([X11PORT], [x11], [if wxWidgets port is wxX11], [WX_PORT="x11"])
            AM_WXSELECTEDCONFIG_CHECK([MGLPORT], [mgl], [if wxWidgets port is wxMGL], [WX_PORT="mgl"])
            AM_WXSELECTEDCONFIG_CHECK([MSWPORT], [msw], [if wxWidgets port is wxMSW], [WX_PORT="msw"])

            dnl in case we are using wxGTK check if we are using GTK 1.x, GTK 2.x or GTK 3.x;
            dnl the user will be able to find the result of the check in the $WX_GTKPORT_VERSION variable
            if test "$WX_PORT" = "gtk"; then
                TEMP=wxlike
                AM_WXSELECTEDCONFIG_CHECK([TEMP], [gtk2], [if wxGTK uses GTK 2.x],
                                        [WX_GTKPORT_VERSION=2], [WX_GTKPORT_VERSION=1])
                dnl Nowadays the default value 'gtk1.2' is decreasingly-plausible, so:
                if test "$WX_GTKPORT_VERSION" = "1"; then
                    AM_WXSELECTEDCONFIG_CHECK([TEMP], [gtk3], [if wxGTK uses GTK 3.x],
                          [WX_GTKPORT_VERSION=3], [WX_GTKPORT_VERSION=1])
                fi
            fi
        else

            dnl FOR DEBUG ONLY
            if test "$DBG_CONFIGURE" = "1"; then
                echo "Using WX_CPPFLAGS: $WX_CPPFLAGS"
            fi

            dnl Before wx2.6.2, wx-config did not have the "--selected_config" option...
            dnl thus we need to extract the info we need from $WX_CPPFLAGS...

            AM_WXFLAGS_CHECK([UNICODE], [unicode], [if wxWidgets was built with UNICODE enabled])
            AM_WXFLAGS_CHECK([DEBUG], [__WXDEBUG__], [if wxWidgets was built in DEBUG mode])
            AM_WXFLAGS_CHECK([STATIC], [static], [if wxWidgets was built in STATIC mode])
            if test "$WX_STATIC" != "0"; then
                WX_SHARED=0
            else
                WX_SHARED=1
            fi

            dnl checks for the wx port used
            WX_PORT="unknown"
            AM_WXFLAGS_CHECK([GTKPORT], [__WXGTK__], [if wxWidgets port is wxGTK], [WX_PORT="gtk"])
            AM_WXFLAGS_CHECK([MOTIFPORT], [__WXMOTIF__], [if wxWidgets port is wxMotif], [WX_PORT="motif"])
            AM_WXFLAGS_CHECK([MACPORT], [__WXMAC__], [if wxWidgets port is wxMac], [WX_PORT="mac"])
            AM_WXFLAGS_CHECK([X11PORT], [__WXX11__], [if wxWidgets port is wxX11], [WX_PORT="x11"])
            AM_WXFLAGS_CHECK([MGLPORT], [__WXMGL__], [if wxWidgets port is wxMGL], [WX_PORT="mgl"])
            AM_WXFLAGS_CHECK([MSWPORT], [__WXMSW__], [if wxWidgets port is wxMSW], [WX_PORT="msw"])

            dnl in case we are using wxGTK check if we are using GTK 1.x or GTK 2.x;
            dnl the user will be able to find the result of the check in the $WX_GTKPORT_VERSION variable
            if test "$WX_PORT" = "gtk"; then
                TEMP=wxlike
                AM_WXFLAGS_CHECK([TEMP], [gtk2], [if wxGTK uses GTK 2.x (instead of GTK 1.x)],
                                        [WX_GTKPORT_VERSION=2], [WX_GTKPORT_VERSION=1])
            fi
        fi


        dnl FOR DEBUG ONLY
        if test "$DBG_CONFIGURE" = "1"; then
            echo "WX_SHARED: $WX_SHARED, WX_DEBUG: $WX_DEBUG, WX_UNICODE: $WX_UNICODE"
            echo "WX_GTKPORT: $WX_GTKPORT, WX_MOTIFPORT: $WX_MOTIFPORT, WX_MACPORT: $WX_MACPORT, "
            echo "WX_X11PORT: $WX_X11PORT, WX_MGLPORT: $WX_MGLPORT, WX_MSWPORT: $WX_MSWPORT"
            echo "WX_PORT: $WX_PORT"
            echo "WX_GTKPORT_VERSION: $WX_GTKPORT_VERSION"
        fi


        dnl nice way to check:
        dnl - that only one of the WX_*PORT variables has been set to 1
        dnl - at least one of the WX_*PORT has been set !

        if test "$WX_PORT" = "unknown" -a "$PORT" = "wxlike" ; then
            AC_MSG_ERROR([
                           Cannot detect the currently installed wxWidgets port !
                           Check your 'wx-config --cxxflags'...
                         ])
        fi

        checksum="$(expr $WX_GTKPORT + $WX_MOTIFPORT + $WX_MACPORT + $WX_X11PORT + $WX_MGLPORT + $WX_MSWPORT)"
        if test "$checksum" = "0" ; then
            AC_MSG_ERROR([
                           Cannot detect the currently installed wxWidgets port !
                           Check your 'wx-config --cxxflags'...
                         ])
        fi
        if test "$checksum" != "1" ; then
            AC_MSG_ERROR([
                           Your 'wx-config --cxxflags' command seems to define more than one port symbol...
                           check your wxWidgets installation (the 'wx-config --list' command may help).
                         ])
        fi
    ])


dnl ---------------------------------------------------------------------------
dnl AM_WXPRESETS_MSG
dnl
dnl Shows a summary message to the user about the WX_* variable contents.
dnl This macro is used typically at the end of the configure script.
dnl ---------------------------------------------------------------------------
AC_DEFUN([AM_WXPRESETS_MSG],
        [
        if test "$WX_DEBUG" = "1" ; then
            echo "  - DEBUG build"
        elif test "$WX_DEBUG" = "0" ; then
            echo "  - RELEASE build"
        else
            echo "  Error in this configure script ! Please contact $PACKAGE_BUGREPORT"
        fi
        if test "$WX_UNICODE" = "1" ; then
            echo "  - UNICODE mode"
        elif test "$WX_UNICODE" = "0" ; then
            echo "  - ANSI mode"
        else
            echo "  Error in this configure script ! Please contact $PACKAGE_BUGREPORT"
        fi
        if test "$WX_SHARED" = "1" ; then
            echo "  - SHARED mode"
        elif test "$WX_SHARED" = "0" ; then
            echo "  - STATIC mode"
        else
            echo "  Error in this configure script ! Please contact $PACKAGE_BUGREPORT"
        fi
        echo "  - VERSION: $WX_VERSION"

        if test "$WX_PORT" = "gtk"; then
            if test "$WX_GTKPORT_VERSION" = "1"; then
                echo "  - PORT: gtk (with GTK+ 1.x)"
            elif test "$WX_GTKPORT_VERSION" = "2" ; then
                echo "  - PORT: gtk (with GTK+ 2.x)"
            elif test "$WX_GTKPORT_VERSION" = "3" ; then
                echo "  - PORT: gtk (with GTK+ 3.x)"
            else
                echo "  Error in this configure script ! Please contact $PACKAGE_BUGREPORT"
            fi
        else
            echo "  - PORT: $WX_PORT"
        fi
    ])


dnl ---------------------------------------------------------------------------
dnl WX_ARG_ENABLE/WX_ARG_WITH
dnl
dnl Two little custom macros which define the ENABLE/WITH configure arguments.
dnl Macro arguments:
dnl $1 = the name of the --enable / --with  feature
dnl $2 = the name of the variable associated
dnl $3 = the description of that feature
dnl $4 = the default value for that feature
dnl $5 = additional action to do in case option is given with "yes" value
dnl ---------------------------------------------------------------------------
AC_DEFUN([WX_ARG_ENABLE],
         [AC_ARG_ENABLE($1,
            AC_HELP_STRING([--enable-$1], [$3 (default is $4)]),
            [], [enableval="$4"])

            dnl Show a message to the user about this option
            AC_MSG_CHECKING([for the --enable-$1 option])
            if test "$enableval" = "yes" ; then
                AC_MSG_RESULT([yes])
                $2=1
                $5
            elif test "$enableval" = "no" ; then
                AC_MSG_RESULT([no])
                $2=0
            elif test "$enableval" = "wxlike" ; then
                AC_MSG_RESULT([will be detected from wxWidgets])
                $2="wxlike"
            else
                AC_MSG_ERROR([unrecognized option value (allowed values: yes, no, wxlike) !])
            fi
         ])

AC_DEFUN([WX_ARG_WITH],
         [AC_ARG_WITH($1,
            AC_HELP_STRING([--with-$1], [$3 (default is $4)]),
            [], [withval="$4"])

            dnl Show a message to the user about this option
            AC_MSG_CHECKING([for the --with-$1 option])
            if test "$withval" = "yes" ; then
                AC_MSG_RESULT([yes])
                $2=1
                $5
dnl NB: we don't allow --with-gtk=no option since it does not make much sense !
dnl            elif test "$withval" = "no" ; then
dnl                AC_MSG_RESULT([no])
dnl                $2=0
            elif test "$withval" = "wxlike" ; then
                AC_MSG_RESULT([will be detected from wxWidgets])
                $2="wxlike"
            else
                AC_MSG_ERROR([unrecognized option value (allowed values: yes, wxlike) !])
            fi
         ])


dnl ---------------------------------------------------------------------------
dnl AM_OPTIONS_WXPRESETS
dnl
dnl Gives to the configure script the following options:
dnl   --enable-static
dnl   --enable-debug
dnl   --enable-unicode
dnl checks for their presence and eventually set the SHARED,DEBUG,UNICODE
dnl variables accordingly.
dnl ---------------------------------------------------------------------------
AC_DEFUN([AM_OPTIONS_WXPRESETS],
        [

        dnl The default values (and also option names) are the same of wx's ones
        WX_ARG_ENABLE([static], [STATIC], [Builds in static mode], [wxlike])
        WX_ARG_ENABLE([unicode], [UNICODE], [Builds in unicode mode], [wxlike])
        WX_ARG_ENABLE([debug], [DEBUG], [Builds in debug mode], [wxlike])

        PORT="wxlike"
        WX_ARG_WITH([motif], [MOTIFPORT], [Uses the wxMotif port], [wxlike], [PORT="motif"])
        WX_ARG_WITH([gtk], [GTKPORT], [Uses the wxGTK port], [wxlike], [PORT="gtk"])
        WX_ARG_WITH([x11], [X11PORT], [Uses the wxX11 port], [wxlike], [PORT="x11"])
        WX_ARG_WITH([mac], [MACPORT], [Uses the wxMac port], [wxlike], [PORT="mac"])
        WX_ARG_WITH([mgl], [MGLPORT], [Uses the wxMGL port], [wxlike], [PORT="mgl"])

        dnl In case we are on Cygwin !
        WX_ARG_WITH([msw], [MSWPORT], [Uses the wxMSW port], [wxlike], [PORT="msw"])

        dnl nice way to check:
        dnl - that only one of the *PORT variables has been set to 1
        dnl - at least one of the *PORT has been set !

        dnl FOR DEBUG ONLY
        if test "$DBG_CONFIGURE" = "1"; then
            echo "STATIC: $STATIC, DEBUG: $DEBUG, UNICODE: $UNICODE, PORT: $PORT"
            echo "GTKPORT: $GTKPORT, X11PORT: $X11PORT, MACPORT: $MACPORT, MOTIFPORT: $MOTIFPORT, MGLPORT: $MGLPORT"
            echo "PORT: $PORT"
        fi
    ])



dnl ---------------------------------------------------------------------------
dnl AM_CONVERT_WXPRESETS_OPTIONS_TO_WXCONFIG_FLAGS
dnl
dnl Sets the WXCFG_FLAGS string using the SHARED,DEBUG,UNICODE variable values
dnl which are different from "wxlike"
dnl ---------------------------------------------------------------------------
AC_DEFUN([AM_CONVERT_WXPRESETS_OPTIONS_TO_WXCONFIG_FLAGS],
        [

        dnl The space at the end of the WXCFG_FLAGS is important; do not remove !
        if test "$STATIC" = "1" ; then
            WXCFG_FLAGS="--static=yes "
        elif test "$STATIC" = "0" ; then
            WXCFG_FLAGS="--static=no "
        fi

        if test "$DEBUG" = "1" ; then
            WXCFG_FLAGS="$WXCFG_FLAGS""--debug=yes "
        elif test "$DEBUG" = "0" ; then
            WXCFG_FLAGS="$WXCFG_FLAGS""--debug=no "
        fi

        if test "$UNICODE" = "1" ; then
            WXCFG_FLAGS="$WXCFG_FLAGS""--unicode=yes "
        elif test "$UNICODE" = "0" ; then
            WXCFG_FLAGS="$WXCFG_FLAGS""--unicode=no "
        fi

        if test "$GTKPORT" = "1" ; then
            WXCFG_FLAGS="$WXCFG_FLAGS""--toolkit=gtk2 "
        elif test "$MOTIFPORT" = "1" ; then
            WXCFG_FLAGS="$WXCFG_FLAGS""--toolkit=motif "
        elif test "$X11PORT" = "1" ; then
            WXCFG_FLAGS="$WXCFG_FLAGS""--toolkit=x11 "
        elif test "$MACPORT" = "1" ; then
            WXCFG_FLAGS="$WXCFG_FLAGS""--toolkit=mac "
        elif test "$MGLPORT" = "1" ; then
            WXCFG_FLAGS="$WXCFG_FLAGS""--toolkit=mgl "
        elif test "$MSWPORT" = "1" ; then
            WXCFG_FLAGS="$WXCFG_FLAGS""--toolkit=msw "
        fi


        dnl FOR DEBUG ONLY
        if test "$DBG_CONFIGURE" = "1"; then
            echo "WXCFG_FLAGS: $WXCFG_FLAGS"
        fi
    ])


dnl ---------------------------------------------------------------------------
dnl AM_GET_GTK_FLAGS
dnl
dnl When using the wxGTK port, this macro creates a GTKPKG_FLAGS variable that
dnl contains the c flags (-I and -D flags) required to compile a program which
dnl uses directly the GTK libraries (instead using the wx layer).
dnl ---------------------------------------------------------------------------
AC_DEFUN([AM_GET_GTK_FLAGS],
        [
            if test "$WX_PORT" = "gtk" ; then
                dnl The commands below were taken from usenet postings by John Labenski
                dnl NB Trying to do GTKPKG_FLAGS=`gtk-config --cflags` fails, you have
                dnl    to use an intermediate var
                if test "$WX_GTKPORT_VERSION" = "1" ; then
                    _GTKPKG_FL="gtk-config --cflags"
                    GTKPKG_FLAGS=`$_GTKPKG_FL`
                elif test "$WX_GTKPORT_VERSION" = "3" ; then
                    _GTKPKG_FL="pkg-config --cflags gtk+-3.0"
                    GTKPKG_FLAGS=`$_GTKPKG_FL`
                else
                    _GTKPKG_FL="pkg-config --cflags gtk+-2.0"
                    GTKPKG_FLAGS=`$_GTKPKG_FL`
                fi
            fi
        ])



dnl ---------------------------------------------------------------------------
dnl AM_WXPRESETS([minimum-wx-version], [addwxlibraries], [addgtkflags])
dnl
dnl where "addwxlibraries" are those wxWidgets libraries (when wx is built
dnl in multilib mode) required by the program to link (e.g. xml,xrc,net,odbc,etc);
dnl the core & base libraries are included by default.
dnl
dnl Just a convenience macro for
dnl  AM_PATH_WXCONFIG([minimum-wx-version], [], [], [addwxlibraries])
dnl  AM_WXPRESETS_CHECK
dnl  AM_GET_GTK_FLAGS   (only when addgtkflags != '')
dnl macros.
dnl ---------------------------------------------------------------------------
AC_DEFUN([AM_WXPRESETS],
         [
            dnl From --enable-* options set by AM_OPTIONS_WXPRESETS, create the
            dnl WXCFG_FLAGS string to give to wx-config
            AM_CONVERT_WXPRESETS_OPTIONS_TO_WXCONFIG_FLAGS

            AM_PATH_WXCONFIG([$1], [wxWin=1], [wxWin=0], [$2,core,base], [$WXCFG_FLAGS])
            if test "$wxWin" != 1; then
                AC_MSG_ERROR([
    The requested wxWidgets build couldn't be found.

    Try to use the default build of wxWidgets
    (try the command 'wx-config --list'); i.e. leave
    the --enable-unicode, --enable-static, --enable-debug
    and --with-* options to their default values.

    If you still get this error, then check that 'wx-config' is
    in path, the directory where wxWidgets libraries are installed
    (returned by 'wx-config --libs' command) is in LD_LIBRARY_PATH
    or equivalent variable and wxWidgets version is $1 or above.
                ])
            else
                dnl do not update CPPFLAGS nor CXXFLAGS doing something like:
                dnl       CPPFLAGS="$CPPFLAGS $WX_CPPFLAGS"
                dnl       CXXFLAGS="$CXXFLAGS $WX_CXXFLAGS"
                dnl otherwise we'll get the
                dnl same settings repetead three times since wxpresets generate a
                dnl Makefile.in which merges these two variables with $WX_CPPFLAGS
                dnl automatically...
                dnl CFLAGS="$CFLAGS $WX_CFLAGS_ONLY"
                dnl LIBS="$LIBS $WX_LIBS"

                dnl FOR DEBUG ONLY
                if test "$DBG_CONFIGURE" = "1"; then
                    echo "WX_LIBS: $WX_LIBS"
                fi
            fi

            dnl Synch our WX_DEBUG,WX_UNICODE,WX_SHARED variables with wx ones
            AM_WXPRESETS_CHECK

            dnl It doesn't matter what "gtkaddflags" parameter contains,
            dnl if it's non-empty it's true
            if test -n "$3" ; then
                dnl Add gtk-specific flags (useful when compiling wx sources
                dnl that directly use the GTK libraries)
                AM_GET_GTK_FLAGS

                dnl Update global flags
                CXXFLAGS="$CXXFLAGS $GTKPKG_FLAGS"
                CFLAGS="$CFLAGS $GTKPKG_FLAGS"
            fi
        ])



dnl ---------------------------------------------------------------------------
dnl AM_WXPRESETS_FULL([minimum-wx-version], [addwxlibraries], [addgtkflags])
dnl
dnl Like AM_WXPRESETS but this macro also does those standard checks
dnl to recognize the system and the installed utility programs
dnl ---------------------------------------------------------------------------
AC_DEFUN([AM_WXPRESETS_FULL],
        [
            dnl This allows us to use Bakefile, recognizing the system type
            dnl (and sets the AC_CANONICAL_BUILD, AC_CANONICAL_HOST and
            dnl AC_CANONICAL_TARGET variables)
            AC_CANONICAL_SYSTEM

            dnl we set these vars to avoid that the AC_PROG_C* macros add the "-g -O2" flags;
            dnl we will add them later, if needed
            CFLAGS=
            CXXFLAGS=
            CPPFLAGS=

            dnl Checks for basic programs used to compile/install.
            AC_PROG_AWK
            AC_PROG_INSTALL
            AC_PROG_LN_S
            AC_PROG_RANLIB
            AC_PROG_CC
            AC_PROG_CXX
            AC_PROG_CXXCPP

            dnl check for wxWidgets library and initialization of WX_* variables
            AM_WXPRESETS([$1], [$2], [$3])

            dnl add the optimize/debug flags
            dnl NOTE1: these checks must be put after AM_WXPRESETS (which sets the $WX_* variables)...
            dnl NOTE2: the CXXFLAGS are merged together with the CPPFLAGS so we don't need to set them, too
            if [[ "$WX_DEBUG" = "1" ]]; then

                dnl NOTE: the -Wundef and -Wno-ctor-dtor-privacy are not enabled automatically by -Wall
                dnl NOTE2: the '-Wno-ctor-dtor-privacy' has sense only when compiling C++ source files
                dnl        and thus we must be careful to add it only to CXXFLAGS and not to CFLAGS
                dnl        (remember that CPPFLAGS is reserved for both C and C++ compilers while
                dnl         CFLAGS is intended as flags for C compiler only and CXXFLAGS for C++ only)
                CXXFLAGS="$CXXFLAGS -g -O0 -Wall -Wundef -Wno-ctor-dtor-privacy"
                CFLAGS="$CFLAGS -g -O0 -Wall -Wundef"
            else
                CXXFLAGS="$CXXFLAGS -O2"
                CFLAGS="$CFLAGS -O2"
            fi
        ])



dnl ---------------------------------------------------------------------------
dnl AM_WXPRESETS_MSG_BEGIN
dnl
dnl Like AM_WXPRESETS_MSG but this macro also gives info about the configuration
dnl of the package which used the wxpresets.
dnl ---------------------------------------------------------------------------
AC_DEFUN([AM_WXPRESETS_MSG_BEGIN],
        [
            echo
            echo " ----------------------------------------------------------------"
            echo "  Configuration for $PACKAGE_NAME $PACKAGE_VERSION successfully completed."
            echo "  Summary of main configuration settings for $PACKAGE_NAME:"
            if [[ "$WX_DEBUG" = "1" ]]; then
                echo "  - DEBUG build"
            else
                echo "  - RELEASE build"
            fi
            if [[ "$WX_UNICODE" = "1" ]]; then
                echo "  - UNICODE mode"
            else
                echo "  - ANSI mode"
            fi
            if [[ "$WX_SHARED" = "1" ]]; then
                echo "  - SHARED mode"
            else
                echo "  - STATIC mode"
            fi
        ])



dnl ---------------------------------------------------------------------------
dnl AM_WXPRESETS_MSG_END
dnl
dnl Like AM_WXPRESETS_MSG but this macro also gives info about the configuration
dnl of the package which used the wxpresets.
dnl ---------------------------------------------------------------------------
AC_DEFUN([AM_WXPRESETS_MSG_END],
        [
            echo
            echo "  The wxWidgets build which will be used by $PACKAGE_NAME $PACKAGE_VERSION"
            echo "  has the following settings:"
            AM_WXPRESETS_MSG
            echo
            echo "  Now, just run make."
            echo " ----------------------------------------------------------------"
            echo
        ])


